@@ -1,7 +1,8 @@
 #ifndef DummyVar_H
 #define DummyVar_H
 
-#include <Rcpp.h>
+#include "SDSUtils.h"
+#include <RcppArmadillo.h>
 
 Rcpp::IntegerMatrix DummyVar(Rcpp::IntegerVector x);
 Rcpp::IntegerMatrix DummyMat(Rcpp::IntegerMatrix mat);
